#
# spec file for package eb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 16
Name:           eb
Version:        4.4.3
Release:        6.3
Summary:        C Library for Accessing CD-ROM Books
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            https://github.com/aehlke/eb
Source:         ftp://ftp.sra.co.jp/pub/misc/eb/%{name}-%{version}.tar.bz2
Patch0:         gettext.patch
# build with gcc14
Patch1:         eb-gcc14.patch
BuildRequires:  libtool
BuildRequires:  zlib-devel
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Summary(ja): EB ライブラリは CD-ROM 書籍にアクセスするための C のライブラリです。
# %description -l ja
# EB ライブラリは CD-ROM 書籍にアクセスするための C のライブラリです。
# UNIX 系 OS のシステム上で動作させることができます。EB, EBG, EBXA, EBXA-C,
# S-EBXA および EPWING 形式の CD-ROM 書籍に対応しています。これらの形式の
# CD-ROM 書籍は、日本で一般的に使われています。CD-ROM 書籍自体は ISO 9660
# 形式になっていますので、他の ISO 9660 形式と同じ要領でマウントすること
# ができます。
#
# 著者:
# ----
#     Motoyuki Kasahara <m-kasahr@sra.co.jp>

%description
EB Library is a C library for accessing CD-ROM books.  It can be built
on UNIX-based systems.	EB Library supports accessing CD-ROM books in
EB, EBG, EBXA, EBXA-C, S-EBXA, and EPWING formats.  CD-ROM books in
those formats are popular in Japan.  Because CD-ROM books themselves
are based on the ISO 9660 format, you can mount the CDs in the same way
as other ISO 9660 CDs.

%package -n libeb%{soname}
Summary:        C Library for Accessing CD-ROM Books - shared library
Group:          System/Libraries

%description -n libeb%{soname}
EB Library is a C library for accessing CD-ROM books.  It can be built
on UNIX-based systems.	EB Library supports accessing CD-ROM books in
EB, EBG, EBXA, EBXA-C, S-EBXA, and EPWING formats.  CD-ROM books in
those formats are popular in Japan.  Because CD-ROM books themselves
are based on the ISO 9660 format, you can mount the CDs in the same way
as other ISO 9660 CDs.

%package devel
Summary:        EB Header Files and Libraries
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Obsoletes:      ebdev < %{version}-%{release}
Provides:       ebdev = %{version}-%{release}
# %description -n ebdev -l ja
# EB ライブラリのヘッダファイル及びライブラリです。

%description devel
EB header files and libraries.

%lang_package

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
	--with-zlib-libraries=/%{_lib} \
	--with-zlib-includes=%{_includedir} \
	--disable-static \
	--with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%find_lang %{name}
%find_lang ebutils %{name}.lang
rm -rf %{buildroot}%{_libdir}/libeb.la

%post -n libeb%{soname} -p /sbin/ldconfig

%postun -n libeb%{soname} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc AUTHORS COPYING NEWS README* ChangeLog*
%{_bindir}/ebappendix
%{_bindir}/ebfont
%{_bindir}/ebinfo
%{_bindir}/ebrefile
%{_bindir}/ebstopcode
%{_bindir}/ebunzip
%{_bindir}/ebzip
%{_bindir}/ebzipinfo
%{_datadir}/eb/
%config %{_sysconfdir}/eb.conf

%files devel
%defattr(-, root, root)
%{_includedir}/eb
%{_libdir}/libeb.so
%{_datadir}/aclocal/eb4.m4

%files -n libeb%{soname}
%defattr(-, root, root)
%{_libdir}/libeb.so.%{soname}
%{_libdir}/libeb.so.%{soname}.0.0

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Mon May 13 2024 pgajdos@suse.com
- added patches
  fix build with gcc14
  + eb-gcc14.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Fri Jul  1 2016 toddrme2178@gmail.com
- Fix Group tag.
* Sat Dec 26 2015 i@marguerite.su
- eb-devel should requires eb, which requires libeb16.
  or applications like ebview won't build because lack
  of /etc/eb.conf
* Tue Jan  6 2015 p.drouand@gmail.com
- Update to version 4.4.3
  + eb/ebnet.c (ebnet_open): Use _atoi64() or atol(), when atoll()
  is not available.
  + configure.ac (LIBEB_VERSION_INFO):
  EB Library verison 4.2.2 sets LIBEB_VERSION_INFO to 15:0:2,
  but it is wrong.  To avoid the confusion, I decide to update
  LIBEB_VERSION_INFO to 16:0:0.
- Split out translation files in a lang subpackage and recommend it
  by the main package
- Split out the system library in libeb16 subpackage; follow shared
  library packaging guidelines
- Do not provide the INSTALL file; we're not concerned
- Update the Url
- Use download Url as source
- Make devel subpackage depends on libeb16 instead of eb
- Remove redudant "eb" in Summary; fix related rpmlint warning
- Remove bugzilla-242268.patch; merged on upstream release
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
- Undebianify ebdev to eb-devel
* Mon Feb 25 2008 crrodriguez@suse.de
- fix library-without-ldconfig-postin errors
- spec file cleanup
- remove libtool archives and static libraries
- use find_lang macro where needed
* Fri Mar 30 2007 ro@suse.de
- added zlib-devel to buildreq
* Tue Feb  6 2007 mfabian@suse.de
- bugzilla #242268: array subscript is above array bounds.
* Tue Feb  6 2007 mfabian@suse.de
- update to 4.3.
  • fix a problem with shared directories with EPWING dictionaries
  • fix the problem that ‘ebunzip --test’ did overwrite the
    main dictionary file.
  • fix the problem that ebappendix created an appendix in
    electronic book form even when reading a catalogs.app file.
  • make colour illustrations with reference links work.
  • API Additions:
    new functions: eb_have_image_menu(), eb_image_menu().
    new text hooks: EB_HOOK_BEGIN_IMAGE_PAGE,
    EB_HOOK_END_IMAGE_PAGE, EB_HOOK_BEGIN_CLICKABLE_AREA,
    EB_HOOK_END_CLICKABLE_AREA
* Wed Feb  8 2006 ro@suse.de
- workaround glibc(?) problem with localedir being .locale
  in configure
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jun  8 2005 tiwai@suse.de
- updated to version 4.2.
* Wed Apr 13 2005 mfabian@suse.de
- use gt_LC_MESSAGES instead of AM_LC_MESSAGES in gettext.m4
  to make it build.
* Tue Dec  7 2004 pth@suse.de
- Fix quoting in AC_DEFUN
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sat Aug 23 2003 mfabian@suse.de
- update to eb-3.3.4.
- use %%run_ldconfig.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Thu Feb 13 2003 mfabian@suse.de
- I forgot "Prereq:       %%install_info_prereq", sorry.
* Wed Feb 12 2003 mfabian@suse.de
- update to eb-3.3
- use %%install_info macro (Bug #23401)
* Tue Aug 13 2002 mfabian@suse.de
- update to eb-3.2.2
  according to the NEWS file:
  * Fix bug in handling of appendix.
  * Fix gettext message catalogs.
  and now the Oxford Concise dictionary works perfectly in UTF-8
  for me with eb-3.2.1 I still had problems using the Oxford
  Concise in UTF-8.
* Fri Apr  5 2002 mfabian@suse.de
- update to eb-3.2.1
- use %%{_libdir}
* Sat Oct 13 2001 mfabian@suse.de
- update to eb-3.1
- move .so symbolic links to dev subpackage
* Tue Mar 27 2001 ro@suse.de
- fixed buildrooting
* Wed Aug 16 2000 mfabian@suse.de
- changed `%%{suse_update_config zlib}' to
  `%%{?suse_update_config:%%{suse_update_config zlib}}'
  to enable building the package outside of the SuSE environment.
* Wed Aug 16 2000 mfabian@suse.de
- changed %%{?suse_update_config} into %%{suse_update_config zlib}
  to make it build on ia64
* Thu Aug 10 2000 mfabian@suse.de
- update to version 2.3.8
* Wed Jul 12 2000 mfabian@suse.de
- new package: eb, Version 2.3.7
